@@ -1,14 +1,14 @@
 package WordList::Phrase::ZH::Idiom::Wiktionary;
 
 our $DATE = '2016-02-10'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 use utf8;
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("num_words_contains_whitespace",0,"longest_word_len",14,"num_words",1116,"shortest_word_len",2,"num_words_contains_unicode",1116,"num_words_contains_nonword_chars",45,"avg_word_len",4.39695340501792); # STATS
+our %STATS = ("avg_word_len",4.44047619047619,"shortest_word_len",2,"num_words_contains_unicode",1008,"num_words_contains_nonword_chars",45,"num_words_contains_whitespace",0,"longest_word_len",14,"num_words",1008); # STATS
 
 1;
 # ABSTRACT: Chinese idioms (chengyu) from wiktionary.org
@@ -23,7 +23,7 @@ WordList::Phrase::ZH::Idiom::Wiktionary - Chinese idioms (chengyu) from wiktiona
 
 =head1 VERSION
 
-This document describes version 0.01 of WordList::Phrase::ZH::Idiom::Wiktionary (from Perl distribution WordList-Phrase-ZH-Idiom-Wiktionary), released on 2016-02-10.
+This document describes version 0.02 of WordList::Phrase::ZH::Idiom::Wiktionary (from Perl distribution WordList-Phrase-ZH-Idiom-Wiktionary), released on 2016-02-10.
 
 =head1 SYNOPSIS
 
@@ -54,11 +54,11 @@ here.
  +----------------------------------+------------------+
  | key                              | value            |
  +----------------------------------+------------------+
- | avg_word_len                     | 4.39695340501792 |
+ | avg_word_len                     | 4.44047619047619 |
  | longest_word_len                 | 14               |
- | num_words                        | 1116             |
+ | num_words                        | 1008             |
  | num_words_contains_nonword_chars | 45               |
- | num_words_contains_unicode       | 1116             |
+ | num_words_contains_unicode       | 1008             |
  | num_words_contains_whitespace    | 0                |
  | shortest_word_len                | 2                |
  +----------------------------------+------------------+
@@ -147,11 +147,6 @@ __DATA__
 万水千山
 万象更新
 三下五除二
-三下五除二
-三下五除二
-三下五除二
-三下五除二
-三下五除二
 三五成羣
 三天打鱼两天晒网
 三更灯火五更鸡
@@ -207,12 +202,6 @@ __DATA__
 东逃西窜
 两下
 两下子
-两下子
-两下子
-两下子
-两下子
-两下子
-两下子
 两害相权取其轻
 丧家之犬
 丧家之狗
@@ -267,17 +256,6 @@ __DATA__
 供不应求
 侪囝饿死父
 信口开河
-信口开河
-信口开河
-信口开河
-信口开河
-信口开河
-信口开河
-信口開河
-信口開河
-信口開河
-信口開河
-信口開河
 信口開河
 信口雌黄
 俯仰无愧
@@ -308,11 +286,6 @@ __DATA__
 兴高采烈
 兵临城下
 兵強將盛
-兵強將盛
-兵強將盛
-兵強將盛
-兵強將盛
-兵強將盛
 兵强将盛
 兵微将寡
 兵精将勇
@@ -331,11 +304,6 @@ __DATA__
 刀枪不入
 分忧共患
 分憂共患
-分憂共患
-分憂共患
-分憂共患
-分憂共患
-分憂共患
 别具一格
 别开生面
 别有洞天
@@ -350,11 +318,6 @@ __DATA__
 功亏一篑
 动手动脚
 助紂為虐
-助紂為虐
-助紂為虐
-助紂為虐
-助紂為虐
-助紂為虐
 助纣为虐
 势不可当
 势均力敌
@@ -381,12 +344,6 @@ __DATA__
 卖友求荣
 卖官鬻爵
 南辕北辙
-南辕北辙
-南辕北辙
-南辕北辙
-南辕北辙
-南辕北辙
-南辕北辙
 南郭处士
 博学强记
 卧薪尝胆
@@ -565,11 +522,6 @@ __DATA__
 弃暗投明
 弄虚作假
 引狼入室
-引狼入室
-引狼入室
-引狼入室
-引狼入室
-引狼入室
 引虎入羊羣
 张三李四
 弥天亘地
@@ -681,17 +633,6 @@ __DATA__
 攻其无备，出其不意
 敢做敢当
 敬賢禮士
-敬賢禮士
-敬賢禮士
-敬賢禮士
-敬賢禮士
-敬賢禮士
-敬贤礼士
-敬贤礼士
-敬贤礼士
-敬贤礼士
-敬贤礼士
-敬贤礼士
 敬贤礼士
 敬酒不吃吃罚酒
 斩将搴旗
@@ -760,17 +701,6 @@ __DATA__
 杀鸡吓猴
 杀鸡给猴看
 杀鸡警猴
-杀鸡警猴
-杀鸡警猴
-杀鸡警猴
-杀鸡警猴
-杀鸡警猴
-杀鸡警猴
-杂乱无章
-杂乱无章
-杂乱无章
-杂乱无章
-杂乱无章
 杂乱无章
 杞人忧天
 束手待毙
@@ -800,12 +730,6 @@ __DATA__
 殊途同归
 残暴不仁
 殺雞警猴
-殺雞警猴
-殺雞警猴
-殺雞警猴
-殺雞警猴
-殺雞警猴
-殺雞警猴
 比手划脚
 毛毛雨
 毛遂自荐
@@ -835,11 +759,6 @@ __DATA__
 涂炭
 涕泗横流
 深更半夜
-深更半夜
-深更半夜
-深更半夜
-深更半夜
-深更半夜
 深沟高垒
 溃不成军
 源源不绝
@@ -1008,17 +927,6 @@ __DATA__
 虎无爪，鸟无翼
 虚无缥缈
 蟾宫折桂
-蟾宫折桂
-蟾宫折桂
-蟾宫折桂
-蟾宫折桂
-蟾宫折桂
-蟾宫折桂
-蟾宮折桂
-蟾宮折桂
-蟾宮折桂
-蟾宮折桂
-蟾宮折桂
 蟾宮折桂
 衣不解带
 衣冠禽兽
@@ -1059,12 +967,6 @@ __DATA__
 贪心不足
 贯斗牛
 赏功罚罪
-赏功罚罪
-赏功罚罪
-赏功罚罪
-赏功罚罪
-赏功罚罪
-赏功罚罪
 赏心悦目
 走来走去
 趁热打铁
@@ -1158,11 +1060,6 @@ __DATA__
 颓墙坏壁
 颠沛流离
 風韻猶存
-風韻猶存
-風韻猶存
-風韻猶存
-風韻猶存
-風韻猶存
 风华正茂
 风和日丽
 风流倜傥
@@ -1175,11 +1072,6 @@ __DATA__
 食之无味，弃之可惜
 食肉寝皮
 飲水思源
-飲水思源
-飲水思源
-飲水思源
-飲水思源
-飲水思源
 饮水思源
 饱餐一顿
 驴唇不对马嘴
